@@ -1,14 +1,19 @@
-from typing import Optional
+from functools import cache
+from typing import Optional, Tuple, Callable
 
 from sweelimiter.api.backend import Backend
-from redis import Redis
+
+try:
+    from redis import Redis
+except ImportError:
+    raise AssertionError('Please install redis to use redis_backend')
 
 
 class RedisBackend(Backend):
 
-    def process(self, key: str, interval_ms: int, limit: int) -> tuple[Optional[str], dict]:
+    async def process(self, key: str, interval_ms: int, limit: int) -> Tuple[Optional[str], dict]:
         redis_key = 'limiter_' + key
-        r = self.r
+        r = self._redis()
 
         seconds, microseconds = r.time()
         time_now = int(seconds * 1000 + microseconds / 1000)
@@ -40,5 +45,9 @@ class RedisBackend(Backend):
             'est_interval': est_interval
         })
 
-    def __init__(self, r: Redis):
-        self.r = r
+    def __init__(self, redis_factory: Callable[[], Redis]):
+        self.redis_factory = redis_factory
+
+    @cache
+    def _redis(self):
+        return self.redis_factory()
